package org.jeecg.modules.ai.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.ai.entity.YsDirectoryMaterialRelation;
import org.jeecg.modules.ai.service.IYsDirectoryMaterialRelationService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 预审事项和预审材料关系表
 * @Author: jeecg-boot
 * @Date:   2023-12-08
 * @Version: V1.0
 */
@Api(tags="预审事项和预审材料关系表")
@RestController
@RequestMapping("/ai/ysDirectoryMaterialRelation")
@Slf4j
public class YsDirectoryMaterialRelationController extends JeecgController<YsDirectoryMaterialRelation, IYsDirectoryMaterialRelationService> {
	@Autowired
	private IYsDirectoryMaterialRelationService ysDirectoryMaterialRelationService;
	
	/**
	 * 分页列表查询
	 *
	 * @param ysDirectoryMaterialRelation
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@AutoLog(value = "预审事项和预审材料关系表-分页列表查询")
	@ApiOperation(value="预审事项和预审材料关系表-分页列表查询", notes="预审事项和预审材料关系表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<?> queryPageList(YsDirectoryMaterialRelation ysDirectoryMaterialRelation,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<YsDirectoryMaterialRelation> queryWrapper = QueryGenerator.initQueryWrapper(ysDirectoryMaterialRelation, req.getParameterMap());
		Page<YsDirectoryMaterialRelation> page = new Page<YsDirectoryMaterialRelation>(pageNo, pageSize);
		IPage<YsDirectoryMaterialRelation> pageList = ysDirectoryMaterialRelationService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param ysDirectoryMaterialRelation
	 * @return
	 */
	@AutoLog(value = "预审事项和预审材料关系表-添加")
	@ApiOperation(value="预审事项和预审材料关系表-添加", notes="预审事项和预审材料关系表-添加")
	@PostMapping(value = "/add")
	public Result<?> add(@RequestBody YsDirectoryMaterialRelation ysDirectoryMaterialRelation) {
		ysDirectoryMaterialRelationService.save(ysDirectoryMaterialRelation);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param ysDirectoryMaterialRelation
	 * @return
	 */
	@AutoLog(value = "预审事项和预审材料关系表-编辑")
	@ApiOperation(value="预审事项和预审材料关系表-编辑", notes="预审事项和预审材料关系表-编辑")
	@PutMapping(value = "/edit")
	public Result<?> edit(@RequestBody YsDirectoryMaterialRelation ysDirectoryMaterialRelation) {
		ysDirectoryMaterialRelationService.updateById(ysDirectoryMaterialRelation);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "预审事项和预审材料关系表-通过id删除")
	@ApiOperation(value="预审事项和预审材料关系表-通过id删除", notes="预审事项和预审材料关系表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		ysDirectoryMaterialRelationService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "预审事项和预审材料关系表-批量删除")
	@ApiOperation(value="预审事项和预审材料关系表-批量删除", notes="预审事项和预审材料关系表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<?> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.ysDirectoryMaterialRelationService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "预审事项和预审材料关系表-通过id查询")
	@ApiOperation(value="预审事项和预审材料关系表-通过id查询", notes="预审事项和预审材料关系表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<?> queryById(@RequestParam(name="id",required=true) String id) {
		YsDirectoryMaterialRelation ysDirectoryMaterialRelation = ysDirectoryMaterialRelationService.getById(id);
		if(ysDirectoryMaterialRelation==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(ysDirectoryMaterialRelation);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param ysDirectoryMaterialRelation
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, YsDirectoryMaterialRelation ysDirectoryMaterialRelation) {
        return super.exportXls(request, ysDirectoryMaterialRelation, YsDirectoryMaterialRelation.class, "预审事项和预审材料关系表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, YsDirectoryMaterialRelation.class);
    }

}
