package org.jeecg.modules.ai.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.ai.entity.YsEventType;
import org.jeecg.modules.ai.service.IYsEventTypeService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 预审事项类型字典表
 * @Author: jeecg-boot
 * @Date:   2023-12-08
 * @Version: V1.0
 */
@Api(tags="预审事项类型字典表")
@RestController
@RequestMapping("/ai/ysEventType")
@Slf4j
public class YsEventTypeController extends JeecgController<YsEventType, IYsEventTypeService> {
	@Autowired
	private IYsEventTypeService ysEventTypeService;
	
	/**
	 * 分页列表查询
	 *
	 * @param ysEventType
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@AutoLog(value = "预审事项类型字典表-分页列表查询")
	@ApiOperation(value="预审事项类型字典表-分页列表查询", notes="预审事项类型字典表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<?> queryPageList(YsEventType ysEventType,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<YsEventType> queryWrapper = QueryGenerator.initQueryWrapper(ysEventType, req.getParameterMap());
		Page<YsEventType> page = new Page<YsEventType>(pageNo, pageSize);
		IPage<YsEventType> pageList = ysEventTypeService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param ysEventType
	 * @return
	 */
	@AutoLog(value = "预审事项类型字典表-添加")
	@ApiOperation(value="预审事项类型字典表-添加", notes="预审事项类型字典表-添加")
	@PostMapping(value = "/add")
	public Result<?> add(@RequestBody YsEventType ysEventType) {
		ysEventTypeService.save(ysEventType);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param ysEventType
	 * @return
	 */
	@AutoLog(value = "预审事项类型字典表-编辑")
	@ApiOperation(value="预审事项类型字典表-编辑", notes="预审事项类型字典表-编辑")
	@PutMapping(value = "/edit")
	public Result<?> edit(@RequestBody YsEventType ysEventType) {
		ysEventTypeService.updateById(ysEventType);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "预审事项类型字典表-通过id删除")
	@ApiOperation(value="预审事项类型字典表-通过id删除", notes="预审事项类型字典表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		ysEventTypeService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "预审事项类型字典表-批量删除")
	@ApiOperation(value="预审事项类型字典表-批量删除", notes="预审事项类型字典表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<?> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.ysEventTypeService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "预审事项类型字典表-通过id查询")
	@ApiOperation(value="预审事项类型字典表-通过id查询", notes="预审事项类型字典表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<?> queryById(@RequestParam(name="id",required=true) String id) {
		YsEventType ysEventType = ysEventTypeService.getById(id);
		if(ysEventType==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(ysEventType);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param ysEventType
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, YsEventType ysEventType) {
        return super.exportXls(request, ysEventType, YsEventType.class, "预审事项类型字典表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, YsEventType.class);
    }

}
